use lazy_static::lazy_static;
use std::collections::HashMap;

#[derive(Debug, PartialEq, Eq, Clone, Copy)]
pub(crate) enum FieldType {
    Encoded,
    Numeric,
    NumericDec,
    NumericHex,
    NumericOct,
}

lazy_static! {
    pub(crate) static ref EVENT_IDS: HashMap<&'static[u8], u32> = {
        let els: &[(&str, u32)] = &[ ("GET", 1000), ("SET", 1001), ("LIST", 1002), ("ADD", 1003), ("DEL", 1004), ("USER", 1005), ("LOGIN", 1006), ("WATCH_INS", 1007), ("WATCH_REM", 1008), ("WATCH_LIST", 1009), ("SIGNAL_INFO", 1010), ("ADD_RULE", 1011), ("DEL_RULE", 1012), ("LIST_RULES", 1013), ("TRIM", 1014), ("MAKE_EQUIV", 1015), ("TTY_GET", 1016), ("TTY_SET", 1017), ("SET_FEATURE", 1018), ("GET_FEATURE", 1019), ("USER_AUTH", 1100), ("USER_ACCT", 1101), ("USER_MGMT", 1102), ("CRED_ACQ", 1103), ("CRED_DISP", 1104), ("USER_START", 1105), ("USER_END", 1106), ("USER_AVC", 1107), ("USER_CHAUTHTOK", 1108), ("USER_ERR", 1109), ("CRED_REFR", 1110), ("USYS_CONFIG", 1111), ("USER_LOGIN", 1112), ("USER_LOGOUT", 1113), ("ADD_USER", 1114), ("DEL_USER", 1115), ("ADD_GROUP", 1116), ("DEL_GROUP", 1117), ("DAC_CHECK", 1118), ("CHGRP_ID", 1119), ("TEST", 1120), ("TRUSTED_APP", 1121), ("USER_SELINUX_ERR", 1122), ("USER_CMD", 1123), ("USER_TTY", 1124), ("CHUSER_ID", 1125), ("GRP_AUTH", 1126), ("SYSTEM_BOOT", 1127), ("SYSTEM_SHUTDOWN", 1128), ("SYSTEM_RUNLEVEL", 1129), ("SERVICE_START", 1130), ("SERVICE_STOP", 1131), ("GRP_MGMT", 1132), ("GRP_CHAUTHTOK", 1133), ("MAC_CHECK", 1134), ("ACCT_LOCK", 1135), ("ACCT_UNLOCK", 1136), ("USER_DEVICE", 1137), ("SOFTWARE_UPDATE", 1138), ("DAEMON_START", 1200), ("DAEMON_END", 1201), ("DAEMON_ABORT", 1202), ("DAEMON_CONFIG", 1203), ("DAEMON_RECONFIG", 1204), ("DAEMON_ROTATE", 1205), ("DAEMON_RESUME", 1206), ("DAEMON_ACCEPT", 1207), ("DAEMON_CLOSE", 1208), ("DAEMON_ERR", 1209), ("SYSCALL", 1300), ("FS_WATCH", 1301), ("PATH", 1302), ("IPC", 1303), ("SOCKETCALL", 1304), ("CONFIG_CHANGE", 1305), ("SOCKADDR", 1306), ("CWD", 1307), ("EXECVE", 1309), ("IPC_SET_PERM", 1311), ("MQ_OPEN", 1312), ("MQ_SENDRECV", 1313), ("MQ_NOTIFY", 1314), ("MQ_GETSETATTR", 1315), ("KERNEL_OTHER", 1316), ("FD_PAIR", 1317), ("OBJ_PID", 1318), ("TTY", 1319), ("EOE", 1320), ("BPRM_FCAPS", 1321), ("CAPSET", 1322), ("MMAP", 1323), ("NETFILTER_PKT", 1324), ("NETFILTER_CFG", 1325), ("SECCOMP", 1326), ("PROCTITLE", 1327), ("FEATURE_CHANGE", 1328), ("REPLACE", 1329), ("KERN_MODULE", 1330), ("FANOTIFY", 1331), ("TIME_INJOFFSET", 1332), ("TIME_ADJNTPVAL", 1333), ("BPF", 1334), ("EVENT_LISTENER", 1335), ("URINGOP", 1336), ("OPENAT2", 1337), ("DM_CTRL", 1338), ("DM_EVENT", 1339), ("AVC", 1400), ("SELINUX_ERR", 1401), ("AVC_PATH", 1402), ("MAC_POLICY_LOAD", 1403), ("MAC_STATUS", 1404), ("MAC_CONFIG_CHANGE", 1405), ("MAC_UNLBL_ALLOW", 1406), ("MAC_CIPSOV4_ADD", 1407), ("MAC_CIPSOV4_DEL", 1408), ("MAC_MAP_ADD", 1409), ("MAC_MAP_DEL", 1410), ("MAC_IPSEC_ADDSA", 1411), ("MAC_IPSEC_DELSA", 1412), ("MAC_IPSEC_ADDSPD", 1413), ("MAC_IPSEC_DELSPD", 1414), ("MAC_IPSEC_EVENT", 1415), ("MAC_UNLBL_STCADD", 1416), ("MAC_UNLBL_STCDEL", 1417), ("MAC_CALIPSO_ADD", 1418), ("MAC_CALIPSO_DEL", 1419), ("MAC_TASK_CONTEXTS", 1420), ("MAC_OBJ_CONTEXTS", 1421), ("AA", 1500), ("APPARMOR_AUDIT", 1501), ("APPARMOR_ALLOWED", 1502), ("APPARMOR_DENIED", 1503), ("APPARMOR_HINT", 1504), ("APPARMOR_STATUS", 1505), ("APPARMOR_ERROR", 1506), ("APPARMOR_KILL", 1507), ("ANOM_PROMISCUOUS", 1700), ("ANOM_ABEND", 1701), ("ANOM_LINK", 1702), ("ANOM_CREAT", 1703), ("INTEGRITY_DATA", 1800), ("INTEGRITY_METADATA", 1801), ("INTEGRITY_STATUS", 1802), ("INTEGRITY_HASH", 1803), ("INTEGRITY_PCR", 1804), ("INTEGRITY_RULE", 1805), ("INTEGRITY_EVM_XATTR", 1806), ("INTEGRITY_POLICY_RULE", 1807), ("KERNEL", 2000), ("ANOM_LOGIN_FAILURES", 2100), ("ANOM_LOGIN_TIME", 2101), ("ANOM_LOGIN_SESSIONS", 2102), ("ANOM_LOGIN_ACCT", 2103), ("ANOM_LOGIN_LOCATION", 2104), ("ANOM_MAX_DAC", 2105), ("ANOM_MAX_MAC", 2106), ("ANOM_AMTU_FAIL", 2107), ("ANOM_RBAC_FAIL", 2108), ("ANOM_RBAC_INTEGRITY_FAIL", 2109), ("ANOM_CRYPTO_FAIL", 2110), ("ANOM_ACCESS_FS", 2111), ("ANOM_EXEC", 2112), ("ANOM_MK_EXEC", 2113), ("ANOM_ADD_ACCT", 2114), ("ANOM_DEL_ACCT", 2115), ("ANOM_MOD_ACCT", 2116), ("ANOM_ROOT_TRANS", 2117), ("ANOM_LOGIN_SERVICE", 2118), ("RESP_ANOMALY", 2200), ("RESP_ALERT", 2201), ("RESP_KILL_PROC", 2202), ("RESP_TERM_ACCESS", 2203), ("RESP_ACCT_REMOTE", 2204), ("RESP_ACCT_LOCK_TIMED", 2205), ("RESP_ACCT_UNLOCK_TIMED", 2206), ("RESP_ACCT_LOCK", 2207), ("RESP_TERM_LOCK", 2208), ("RESP_SEBOOL", 2209), ("RESP_EXEC", 2210), ("RESP_SINGLE", 2211), ("RESP_HALT", 2212), ("RESP_ORIGIN_BLOCK", 2213), ("RESP_ORIGIN_BLOCK_TIMED", 2214), ("USER_ROLE_CHANGE", 2300), ("ROLE_ASSIGN", 2301), ("ROLE_REMOVE", 2302), ("LABEL_OVERRIDE", 2303), ("LABEL_LEVEL_CHANGE", 2304), ("USER_LABELED_EXPORT", 2305), ("USER_UNLABELED_EXPORT", 2306), ("DEV_ALLOC", 2307), ("DEV_DEALLOC", 2308), ("FS_RELABEL", 2309), ("USER_MAC_POLICY_LOAD", 2310), ("ROLE_MODIFY", 2311), ("USER_MAC_CONFIG_CHANGE", 2312), ("USER_MAC_STATUS", 2313), ("CRYPTO_TEST_USER", 2400), ("CRYPTO_PARAM_CHANGE_USER", 2401), ("CRYPTO_LOGIN", 2402), ("CRYPTO_LOGOUT", 2403), ("CRYPTO_KEY_USER", 2404), ("CRYPTO_FAILURE_USER", 2405), ("CRYPTO_REPLAY_USER", 2406), ("CRYPTO_SESSION", 2407), ("CRYPTO_IKE_SA", 2408), ("CRYPTO_IPSEC_SA", 2409), ("VIRT_CONTROL", 2500), ("VIRT_RESOURCE", 2501), ("VIRT_MACHINE_ID", 2502), ("VIRT_INTEGRITY_CHECK", 2503), ("VIRT_CREATE", 2504), ("VIRT_DESTROY", 2505), ("VIRT_MIGRATE_IN", 2506), ("VIRT_MIGRATE_OUT", 2507),  ];
        let mut hm = HashMap::with_capacity(els.len());
        for (name, value) in els {
            hm.insert(name.as_bytes(), *value);
        }
        hm
    };
    pub(crate)  static ref EVENT_NAMES: HashMap<u32, &'static str> = {
        let els: &[(&str, u32)] = &[ ("GET", 1000), ("SET", 1001), ("LIST", 1002), ("ADD", 1003), ("DEL", 1004), ("USER", 1005), ("LOGIN", 1006), ("WATCH_INS", 1007), ("WATCH_REM", 1008), ("WATCH_LIST", 1009), ("SIGNAL_INFO", 1010), ("ADD_RULE", 1011), ("DEL_RULE", 1012), ("LIST_RULES", 1013), ("TRIM", 1014), ("MAKE_EQUIV", 1015), ("TTY_GET", 1016), ("TTY_SET", 1017), ("SET_FEATURE", 1018), ("GET_FEATURE", 1019), ("USER_AUTH", 1100), ("USER_ACCT", 1101), ("USER_MGMT", 1102), ("CRED_ACQ", 1103), ("CRED_DISP", 1104), ("USER_START", 1105), ("USER_END", 1106), ("USER_AVC", 1107), ("USER_CHAUTHTOK", 1108), ("USER_ERR", 1109), ("CRED_REFR", 1110), ("USYS_CONFIG", 1111), ("USER_LOGIN", 1112), ("USER_LOGOUT", 1113), ("ADD_USER", 1114), ("DEL_USER", 1115), ("ADD_GROUP", 1116), ("DEL_GROUP", 1117), ("DAC_CHECK", 1118), ("CHGRP_ID", 1119), ("TEST", 1120), ("TRUSTED_APP", 1121), ("USER_SELINUX_ERR", 1122), ("USER_CMD", 1123), ("USER_TTY", 1124), ("CHUSER_ID", 1125), ("GRP_AUTH", 1126), ("SYSTEM_BOOT", 1127), ("SYSTEM_SHUTDOWN", 1128), ("SYSTEM_RUNLEVEL", 1129), ("SERVICE_START", 1130), ("SERVICE_STOP", 1131), ("GRP_MGMT", 1132), ("GRP_CHAUTHTOK", 1133), ("MAC_CHECK", 1134), ("ACCT_LOCK", 1135), ("ACCT_UNLOCK", 1136), ("USER_DEVICE", 1137), ("SOFTWARE_UPDATE", 1138), ("DAEMON_START", 1200), ("DAEMON_END", 1201), ("DAEMON_ABORT", 1202), ("DAEMON_CONFIG", 1203), ("DAEMON_RECONFIG", 1204), ("DAEMON_ROTATE", 1205), ("DAEMON_RESUME", 1206), ("DAEMON_ACCEPT", 1207), ("DAEMON_CLOSE", 1208), ("DAEMON_ERR", 1209), ("SYSCALL", 1300), ("FS_WATCH", 1301), ("PATH", 1302), ("IPC", 1303), ("SOCKETCALL", 1304), ("CONFIG_CHANGE", 1305), ("SOCKADDR", 1306), ("CWD", 1307), ("EXECVE", 1309), ("IPC_SET_PERM", 1311), ("MQ_OPEN", 1312), ("MQ_SENDRECV", 1313), ("MQ_NOTIFY", 1314), ("MQ_GETSETATTR", 1315), ("KERNEL_OTHER", 1316), ("FD_PAIR", 1317), ("OBJ_PID", 1318), ("TTY", 1319), ("EOE", 1320), ("BPRM_FCAPS", 1321), ("CAPSET", 1322), ("MMAP", 1323), ("NETFILTER_PKT", 1324), ("NETFILTER_CFG", 1325), ("SECCOMP", 1326), ("PROCTITLE", 1327), ("FEATURE_CHANGE", 1328), ("REPLACE", 1329), ("KERN_MODULE", 1330), ("FANOTIFY", 1331), ("TIME_INJOFFSET", 1332), ("TIME_ADJNTPVAL", 1333), ("BPF", 1334), ("EVENT_LISTENER", 1335), ("URINGOP", 1336), ("OPENAT2", 1337), ("DM_CTRL", 1338), ("DM_EVENT", 1339), ("AVC", 1400), ("SELINUX_ERR", 1401), ("AVC_PATH", 1402), ("MAC_POLICY_LOAD", 1403), ("MAC_STATUS", 1404), ("MAC_CONFIG_CHANGE", 1405), ("MAC_UNLBL_ALLOW", 1406), ("MAC_CIPSOV4_ADD", 1407), ("MAC_CIPSOV4_DEL", 1408), ("MAC_MAP_ADD", 1409), ("MAC_MAP_DEL", 1410), ("MAC_IPSEC_ADDSA", 1411), ("MAC_IPSEC_DELSA", 1412), ("MAC_IPSEC_ADDSPD", 1413), ("MAC_IPSEC_DELSPD", 1414), ("MAC_IPSEC_EVENT", 1415), ("MAC_UNLBL_STCADD", 1416), ("MAC_UNLBL_STCDEL", 1417), ("MAC_CALIPSO_ADD", 1418), ("MAC_CALIPSO_DEL", 1419), ("MAC_TASK_CONTEXTS", 1420), ("MAC_OBJ_CONTEXTS", 1421), ("AA", 1500), ("APPARMOR_AUDIT", 1501), ("APPARMOR_ALLOWED", 1502), ("APPARMOR_DENIED", 1503), ("APPARMOR_HINT", 1504), ("APPARMOR_STATUS", 1505), ("APPARMOR_ERROR", 1506), ("APPARMOR_KILL", 1507), ("ANOM_PROMISCUOUS", 1700), ("ANOM_ABEND", 1701), ("ANOM_LINK", 1702), ("ANOM_CREAT", 1703), ("INTEGRITY_DATA", 1800), ("INTEGRITY_METADATA", 1801), ("INTEGRITY_STATUS", 1802), ("INTEGRITY_HASH", 1803), ("INTEGRITY_PCR", 1804), ("INTEGRITY_RULE", 1805), ("INTEGRITY_EVM_XATTR", 1806), ("INTEGRITY_POLICY_RULE", 1807), ("KERNEL", 2000), ("ANOM_LOGIN_FAILURES", 2100), ("ANOM_LOGIN_TIME", 2101), ("ANOM_LOGIN_SESSIONS", 2102), ("ANOM_LOGIN_ACCT", 2103), ("ANOM_LOGIN_LOCATION", 2104), ("ANOM_MAX_DAC", 2105), ("ANOM_MAX_MAC", 2106), ("ANOM_AMTU_FAIL", 2107), ("ANOM_RBAC_FAIL", 2108), ("ANOM_RBAC_INTEGRITY_FAIL", 2109), ("ANOM_CRYPTO_FAIL", 2110), ("ANOM_ACCESS_FS", 2111), ("ANOM_EXEC", 2112), ("ANOM_MK_EXEC", 2113), ("ANOM_ADD_ACCT", 2114), ("ANOM_DEL_ACCT", 2115), ("ANOM_MOD_ACCT", 2116), ("ANOM_ROOT_TRANS", 2117), ("ANOM_LOGIN_SERVICE", 2118), ("RESP_ANOMALY", 2200), ("RESP_ALERT", 2201), ("RESP_KILL_PROC", 2202), ("RESP_TERM_ACCESS", 2203), ("RESP_ACCT_REMOTE", 2204), ("RESP_ACCT_LOCK_TIMED", 2205), ("RESP_ACCT_UNLOCK_TIMED", 2206), ("RESP_ACCT_LOCK", 2207), ("RESP_TERM_LOCK", 2208), ("RESP_SEBOOL", 2209), ("RESP_EXEC", 2210), ("RESP_SINGLE", 2211), ("RESP_HALT", 2212), ("RESP_ORIGIN_BLOCK", 2213), ("RESP_ORIGIN_BLOCK_TIMED", 2214), ("USER_ROLE_CHANGE", 2300), ("ROLE_ASSIGN", 2301), ("ROLE_REMOVE", 2302), ("LABEL_OVERRIDE", 2303), ("LABEL_LEVEL_CHANGE", 2304), ("USER_LABELED_EXPORT", 2305), ("USER_UNLABELED_EXPORT", 2306), ("DEV_ALLOC", 2307), ("DEV_DEALLOC", 2308), ("FS_RELABEL", 2309), ("USER_MAC_POLICY_LOAD", 2310), ("ROLE_MODIFY", 2311), ("USER_MAC_CONFIG_CHANGE", 2312), ("USER_MAC_STATUS", 2313), ("CRYPTO_TEST_USER", 2400), ("CRYPTO_PARAM_CHANGE_USER", 2401), ("CRYPTO_LOGIN", 2402), ("CRYPTO_LOGOUT", 2403), ("CRYPTO_KEY_USER", 2404), ("CRYPTO_FAILURE_USER", 2405), ("CRYPTO_REPLAY_USER", 2406), ("CRYPTO_SESSION", 2407), ("CRYPTO_IKE_SA", 2408), ("CRYPTO_IPSEC_SA", 2409), ("VIRT_CONTROL", 2500), ("VIRT_RESOURCE", 2501), ("VIRT_MACHINE_ID", 2502), ("VIRT_INTEGRITY_CHECK", 2503), ("VIRT_CREATE", 2504), ("VIRT_DESTROY", 2505), ("VIRT_MIGRATE_IN", 2506), ("VIRT_MIGRATE_OUT", 2507),  ];
        let mut hm = HashMap::with_capacity(els.len());
        for (name, value) in els {
            hm.insert(*value, *name);
        }
        hm
    };
    pub(crate)  static ref FIELD_TYPES: HashMap<&'static[u8],FieldType> = {
        let els: &[(&str, FieldType)] = &[ ("acct", FieldType::Encoded),("action", FieldType::Numeric),("added", FieldType::Numeric),("addr", FieldType::Encoded),("apparmor", FieldType::Encoded),("arch", FieldType::NumericHex),("argc", FieldType::NumericDec),("audit_backlog_limit", FieldType::NumericDec),("audit_backlog_wait_time", FieldType::NumericDec),("audit_enabled", FieldType::NumericDec),("audit_failure", FieldType::NumericDec),("auid", FieldType::NumericDec),("capability", FieldType::NumericDec),("cap_fe", FieldType::NumericDec),("cap_fi", FieldType::NumericHex),("cap_fp", FieldType::NumericHex),("cap_fver", FieldType::NumericHex),("cap_pa", FieldType::NumericHex),("cap_pe", FieldType::NumericHex),("cap_pi", FieldType::NumericHex),("cap_pp", FieldType::NumericHex),("cgroup", FieldType::Encoded),("changed", FieldType::NumericDec),("cmd", FieldType::Encoded),("code", FieldType::NumericHex),("comm", FieldType::Encoded),("compat", FieldType::NumericDec),("cwd", FieldType::Encoded),("data", FieldType::Encoded),("dev", FieldType::Numeric),("device", FieldType::Encoded),("dir", FieldType::Encoded),("dmac", FieldType::Numeric),("dport", FieldType::NumericDec),("egid", FieldType::NumericDec),("enforcing", FieldType::NumericDec),("entries", FieldType::NumericDec),("errno", FieldType::NumericDec),("euid", FieldType::NumericDec),("exe", FieldType::Encoded),("exit", FieldType::NumericDec),("family", FieldType::NumericDec),("fd", FieldType::NumericDec),("file", FieldType::Encoded),("flags", FieldType::NumericHex),("fe", FieldType::NumericDec),("fi", FieldType::NumericHex),("fp", FieldType::NumericHex),("fsgid", FieldType::NumericDec),("fsuid", FieldType::NumericDec),("fver", FieldType::NumericHex),("gid", FieldType::NumericDec),("grp", FieldType::Encoded),("hook", FieldType::Numeric),("icmp_type", FieldType::Numeric),("id", FieldType::Numeric),("igid", FieldType::NumericDec),("inif", FieldType::Numeric),("ipid", FieldType::NumericDec),("ino", FieldType::NumericDec),("inode", FieldType::NumericDec),("inode_gid", FieldType::NumericDec),("inode_uid", FieldType::NumericDec),("invalid_context", FieldType::Encoded),("ioctlcmd", FieldType::NumericHex),("ipx-net", FieldType::Numeric),("item", FieldType::NumericDec),("items", FieldType::NumericDec),("iuid", FieldType::NumericDec),("key", FieldType::Encoded),("ksize", FieldType::Numeric),("len", FieldType::NumericDec),("lport", FieldType::NumericDec),("list", FieldType::NumericDec),("macproto", FieldType::Numeric),("maj", FieldType::Numeric),("major", FieldType::NumericDec),("minor", FieldType::NumericDec),("mode", FieldType::NumericOct),("nargs", FieldType::NumericDec),("name", FieldType::Encoded),("new", FieldType::Numeric),("new-chardev", FieldType::Encoded),("new-disk", FieldType::Encoded),("new-enabled", FieldType::NumericDec),("new-fs", FieldType::Encoded),("new_gid", FieldType::NumericDec),("new_lock", FieldType::NumericDec),("new-log_passwd", FieldType::NumericDec),("new-mem", FieldType::Numeric),("new-net", FieldType::Encoded),("new_pe", FieldType::Numeric),("new_pi", FieldType::Numeric),("new_pp", FieldType::Numeric),("new-rng", FieldType::Encoded),("new-vcpu", FieldType::Numeric),("nlnk-fam", FieldType::Numeric),("nlnk-grp", FieldType::Numeric),("nlnk-pid", FieldType::NumericDec),("oauid", FieldType::NumericDec),("obj_gid", FieldType::NumericDec),("obj_uid", FieldType::NumericDec),("oflag", FieldType::Numeric),("ogid", FieldType::NumericDec),("ocomm", FieldType::Encoded),("old", FieldType::Numeric),("old", FieldType::Numeric),("old-auid", FieldType::NumericDec),("old-chardev", FieldType::Encoded),("old-disk", FieldType::Encoded),("old-enabled", FieldType::NumericDec),("old_enforcing", FieldType::NumericDec),("old-fs", FieldType::Encoded),("old_lock", FieldType::NumericDec),("old-log_passwd", FieldType::NumericDec),("old-mem", FieldType::Numeric),("old-net", FieldType::Encoded),("old_pa", FieldType::NumericHex),("old_pe", FieldType::NumericHex),("old_pi", FieldType::NumericHex),("old_pp", FieldType::NumericHex),("old_prom", FieldType::NumericDec),("old-rng", FieldType::Encoded),("old-ses", FieldType::NumericDec),("old_val", FieldType::NumericDec),("old-vcpu", FieldType::Numeric),("opid", FieldType::NumericDec),("oses", FieldType::NumericDec),("ouid", FieldType::NumericDec),("outif", FieldType::Numeric),("pa", FieldType::NumericHex),("pe", FieldType::NumericHex),("pi", FieldType::NumericHex),("pp", FieldType::NumericHex),("parent", FieldType::Numeric),("path", FieldType::Encoded),("per", FieldType::NumericHex),("perm", FieldType::Numeric),("perm_mask", FieldType::Numeric),("permissive", FieldType::NumericDec),("pid", FieldType::NumericDec),("ppid", FieldType::NumericDec),("prom", FieldType::NumericDec),("proctitle", FieldType::Encoded),("prog-id", FieldType::NumericDec),("proto", FieldType::NumericDec),("qbytes", FieldType::NumericHex),("rdev", FieldType::Numeric),("removed", FieldType::Numeric),("res", FieldType::NumericDec),("rport", FieldType::NumericDec),("saddr", FieldType::Encoded),("sauid", FieldType::NumericDec),("seqno", FieldType::NumericDec),("ses", FieldType::NumericDec),("sgid", FieldType::NumericDec),("sig", FieldType::NumericDec),("sigev_signo", FieldType::NumericDec),("smac", FieldType::Numeric),("spid", FieldType::NumericDec),("sport", FieldType::NumericDec),("suid", FieldType::NumericDec),("syscall", FieldType::NumericDec),("uid", FieldType::NumericDec),("uring_op", FieldType::NumericDec),("val", FieldType::NumericDec),("ver", FieldType::Numeric),("vm", FieldType::Encoded),("vm-pid", FieldType::NumericDec),("watch", FieldType::Encoded), ];
        let mut hm = HashMap::with_capacity(els.len());
        for (name, typ) in els {
            hm.insert(name.as_bytes(), *typ);
        }
        hm
    };
}
